# qtgrid

[1]:  https://www.riverbankcomputing.com/software/pyqt/     "PyQt"
[2]:  https://www.qt.io/qt-for-python                       "PySide6"
[3]:  https://devlog42.github.io/qtgrid/reference/          "Reference Manual"
[4]:  https://devlog42.github.io/qtgrid/tutorial/           "qtgrid Tutorial"
[5]:  https://devlog42.github.io/qtgrid/api/                "API Documentation"
[6]:  https://github.com/devlog42/repo-skeleton/issues      "Issues Page"
[7]:  https://github.com/devlog42/qtgrid/blob/main/.github/CONTRIBUTING.md    "Contributing"
[8]:  https://github.com/devlog42/qtgrid/blob/main/.github/CODE_OF_CONDUCT.md "Code of Conduct"
[9]:  https://devlog42.github.io/qtgrid                     "Documentation Homepage"
[10]: https://github.com/devlog42/qtgrid/blob/main/LICENSE  "License"

This python **qtgrid** package is for [PyQt][1], or [PySide][2] developers. It helps to build *QGridLayout's* dynamically and with visual help during implementation time. Note that **qtgrid** works in the same way for PyQt6, PyQt5, and PySide6.

Please visit the [documentation homepage][9] to find an example usage, a [tutorial][4], a [reference manual][3], and for the brave the [API Documentation][5].

## Install

Use pip or pipenv

- pip install qtgrid
- pipenv install qtgrid

Get the current development source from GitHub

- git clone https://github.com/devlog42/qtgrid

When importing **qtgrid**, for an installation of PyQt6, PyQt5, or PySide6 is tested in that order.
If none of these are found, a corresponding error message is issued.

## Contribution

Every contribution that advances this project is very welcome.

If you want to report a bug or ask about a new feature, please visit the dedicated [issues][6] page. There you'll find suitable templates for your request, including one that is esspecially intended for mistakes in the documentations.

However, if you want to get involved in development, please check out the [Contribution][7] page first.

When you write posts, it goes without saying that you use a friendly language. Of course there is also a separate page on the topic called [Code of Conduct][8].

## License

The [License][10] of this package comes in terms of *GNU LGPLv3*.
